import git from '../.utils/git-cli';
/**
 * Repository manager
 */
export declare class Repository {
    /**
     * Directory that contains repository (contains `.git` directory)
     */
    readonly location: string;
    /**
     * Shortcut to execute git command in repository
     */
    readonly execute: Repository.BindedGit;
    /**
     * @param location Directory of repository
     */
    constructor(location: string);
    /**
     * Tags manager
     */
    get tags(): Repository.Tags;
}
export declare namespace Repository {
    /**
     * SubCommand executor (abstract)
     */
    abstract class SubCmd extends Repository {
        protected abstract readonly subCmdName: string;
        /**
         * Shortcut to execute git subcommand
         */
        readonly command: BindedGit;
        /**
         * @param location Directory of repository
         */
        constructor(location: string);
    }
    /**
     * Tags manager
     */
    class Tags extends SubCmd {
        readonly subCmdName = "tag";
        /**
         * Get all tags in repository
         */
        getAllTags(): string[];
        /**
         * Add tag to current commit
         * @param name Tag name
         */
        addTag(name: string): void;
    }
    type BindedGit = (args: git.Argv, options?: git.Options) => git.Result;
}
export default Repository;
