"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const git_cli_1 = tslib_1.__importDefault(require("../.utils/git-cli"));
/**
 * Repository manager
 */
class Repository {
    /**
     * @param location Directory of repository
     */
    constructor(location) {
        this.location = location;
        this.execute = (args, options) => git_cli_1.default(location, args, options);
    }
    /**
     * Tags manager
     */
    get tags() {
        return new Repository.Tags(this.location);
    }
}
exports.Repository = Repository;
(function (Repository) {
    /**
     * SubCommand executor (abstract)
     */
    class SubCmd extends Repository {
        /**
         * @param location Directory of repository
         */
        constructor(location) {
            super(location);
            const { execute } = this;
            this.command = (args, options) => execute([this.subCmdName, ...args], options);
        }
    }
    Repository.SubCmd = SubCmd;
    /**
     * Tags manager
     */
    class Tags extends SubCmd {
        constructor() {
            super(...arguments);
            this.subCmdName = 'tag';
        }
        /**
         * Get all tags in repository
         */
        getAllTags() {
            return this.command([]).split(/\n|\r/).filter(Boolean);
        }
        /**
         * Add tag to current commit
         * @param name Tag name
         */
        addTag(name) {
            this.command([name]);
        }
    }
    Repository.Tags = Tags;
})(Repository = exports.Repository || (exports.Repository = {}));
exports.default = Repository;
//# sourceMappingURL=index.js.map